#

##

##

##

    	shows

    		deprecatedish.. use shows_v2

    	itinerary
    		measured ingredients

    		unmeasured ingredients:
    			# LLM

    		partially measured ingredients:

    		recipe {
    			"essential nutrients"
    			"cautionary nutrients"
    		}

    		nature: {
    			"emblem": "",

    			"USDA_food": {},
    			"NIH_supp": {},

    			"affiliate": {
    				"links": []
    			},

    			"nature": nature/nature.r.HTML
    		}

    		land:
    			natures:
    			measures:
    			grove:

    		land_essential_nutrients
    		land_cautionary_ingredients

    	important
    		ingredient_scan

    		ingredient_scan_recipe/formulate/essential_nutrients
    		ingredient_scan_recipe/formulate/cautionary_ingredients

    	vernacular
    		nature:
    			# treasure

    			this is a food or supplement

    		land
    			# topic
    			#